import { Meta } from "@storybook/addon-docs";

<Meta title="Introduction/Developer Guides/Dealing with IDs" />

# Developer Guides

## Dealing with Ids

In HTML the "id" attribute is used to uniquely identify an element within a document. The requirement for unique IDs is crucial for several reasons. While HTML allows to assign the same ID to multiple elements, doing so is not recommended and can lead to unexpected behavior. It is considered a best practice to maintain unique IDs for each element to ensure proper functionality, maintainability, and adherence to web standards.
To enhance clarity and consistency, it is recommended to follow the naming convention for IDs. Meaningful and consistent ID names contribute to better code readability and understanding. In general, the use of IDs should be avoided whenever possible, especially for CSS styling reasons.

<strong>Naming Convention Id Value</strong>

`location-elementNameElement-type`

<strong>Location</strong>

This could relate to the template or page the Id is used for

<strong>Element Name</strong>

This could relate to an element name, component name or a specific action name the Id is used for

<strong>Element Type</strong>

This could relate to an element type, component type or a specific action type the Id is used for

<strong>Example 1</strong>

Id of a form element that's required for the reorder form on the MyMachine Detail Page

Location is `myMachineDetail` followed by `-` followed by ElementName which in that case is `reorder` followed by `-` followed by ElementType which in that case is `form`.

`myMachineDetail-reorder-form`

```
<div>
    <form
        id="myMachineDetail-reorder-form"
        action="#"
    >
          <input type="text" id="name" name="name" />
    </form>
    <button
        type="submit"
        form="myMachineDetail-reorder-form"
        class="ux-button"
    >
        Form submit
    </button>
</div>
```

<strong>Example 2</strong>

Id of Stories teaser section that's required for using anchor links on the Trumpf Newsroom Page

Location is `newsroom` followed by `-` followed by ElementName which in that case is `stories` followed by `-` followed by ElementType which in that case is `teaser`.

`newsroom-stories-teaser`

```
<section id="newsroom-stories-teaser"></section>
```

<strong>Additional Info</strong>

Allowed Characters for HTML attributes:

<a
    href="https://html.spec.whatwg.org/multipage/syntax.html#attributes-2"
    target="_blank"
>
    https://html.spec.whatwg.org/multipage/syntax.html#attributes-2
</a>
